package com.bsv.persistence.domains;

import javax.persistence.AttributeOverride;
import javax.persistence.AttributeOverrides;
import javax.persistence.Column;
import javax.persistence.EmbeddedId;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;

import com.bankserv.common.db.BaseEntity;

/**
 * CmcisBranches entity. 
 * @author Lucky Modiba
 */
@SuppressWarnings({ "serial", "rawtypes" })
@Entity
@Table(name = "CMCIS_BRANCHES", schema = "ICMSOWNER", uniqueConstraints = @UniqueConstraint(columnNames = {
		"MEMBER_NO", "REFERENCE_ID" }))
public class CmcisBranchesDomain extends BaseEntity implements java.io.Serializable {

	// Fields

	private CmcisBranchesId id;
	private CmcisMembersDomain cmcisMembers;

	// Constructors

	/** default constructor */
	public CmcisBranchesDomain() {
	}

	/** full constructor */
	public CmcisBranchesDomain(CmcisBranchesId id, CmcisMembersDomain cmcisMembers) {
		this.id = id;
		this.cmcisMembers = cmcisMembers;
	}

	// Property accessors
	@EmbeddedId
	@AttributeOverrides({
			@AttributeOverride(name = "branchNo", column = @Column(name = "BRANCH_NO", nullable = false, length = 8)),
			@AttributeOverride(name = "branchName", column = @Column(name = "BRANCH_NAME", length = 30)),
			@AttributeOverride(name = "division", column = @Column(name = "DIVISION", length = 30)),
			@AttributeOverride(name = "abbrDivisionName", column = @Column(name = "ABBR_DIVISION_NAME", length = 6)),
			@AttributeOverride(name = "memberNo", column = @Column(name = "MEMBER_NO", nullable = false, precision = 6, scale = 0)),
			@AttributeOverride(name = "icash", column = @Column(name = "ICASH", length = 1)),
			@AttributeOverride(name = "orderSite", column = @Column(name = "ORDER_SITE", length = 25)),
			@AttributeOverride(name = "citSite", column = @Column(name = "CIT_SITE", length = 25)),
			@AttributeOverride(name = "bankRegion", column = @Column(name = "BANK_REGION", length = 3)),
			@AttributeOverride(name = "institutionType", column = @Column(name = "INSTITUTION_TYPE", length = 4)),
			@AttributeOverride(name = "addressLine1", column = @Column(name = "ADDRESS_LINE_1", length = 48)),
			@AttributeOverride(name = "addressLine2", column = @Column(name = "ADDRESS_LINE_2", length = 48)),
			@AttributeOverride(name = "addressLine3", column = @Column(name = "ADDRESS_LINE_3", length = 48)),
			@AttributeOverride(name = "city", column = @Column(name = "CITY", length = 30)),
			@AttributeOverride(name = "postCode", column = @Column(name = "POST_CODE", length = 6)),
			@AttributeOverride(name = "country", column = @Column(name = "COUNTRY", length = 35)),
			@AttributeOverride(name = "countryCode", column = @Column(name = "COUNTRY_CODE", precision = 2, scale = 0)),
			@AttributeOverride(name = "poBoxNo", column = @Column(name = "PO_BOX_NO", length = 35)),
			@AttributeOverride(name = "postOffice", column = @Column(name = "POST_OFFICE", length = 20)),
			@AttributeOverride(name = "postalCity", column = @Column(name = "POSTAL_CITY", length = 35)),
			@AttributeOverride(name = "postalPostCode", column = @Column(name = "POSTAL_POST_CODE", length = 6)),
			@AttributeOverride(name = "postalProvince", column = @Column(name = "POSTAL_PROVINCE", length = 35)),
			@AttributeOverride(name = "postalCountry", column = @Column(name = "POSTAL_COUNTRY", length = 35)),
			@AttributeOverride(name = "areaCode", column = @Column(name = "AREA_CODE", length = 20)),
			@AttributeOverride(name = "telNo", column = @Column(name = "TEL_NO", length = 14)),
			@AttributeOverride(name = "faxNo", column = @Column(name = "FAX_NO", length = 14)),
			@AttributeOverride(name = "emailAddress", column = @Column(name = "EMAIL_ADDRESS", length = 40)),
			@AttributeOverride(name = "telexNo1", column = @Column(name = "TELEX_NO_1", length = 20)),
			@AttributeOverride(name = "telexNo2", column = @Column(name = "TELEX_NO_2", length = 20)),
			@AttributeOverride(name = "telegraphicAddress", column = @Column(name = "TELEGRAPHIC_ADDRESS", length = 24)),
			@AttributeOverride(name = "deletionRequestDate", column = @Column(name = "DELETION_REQUEST_DATE", length = 7)),
			@AttributeOverride(name = "dateLastChanged", column = @Column(name = "DATE_LAST_CHANGED", length = 7)),
			@AttributeOverride(name = "referenceId", column = @Column(name = "REFERENCE_ID", nullable = false, length = 25)),
			@AttributeOverride(name = "selectionId", column = @Column(name = "SELECTION_ID", length = 25)),
			@AttributeOverride(name = "routingId", column = @Column(name = "ROUTING_ID", length = 25)),
			@AttributeOverride(name = "costCentre", column = @Column(name = "COST_CENTRE", nullable = false, length = 25)),
			@AttributeOverride(name = "wholesaleDistribInd", column = @Column(name = "WHOLESALE_DISTRIB_IND", length = 1)),
			@AttributeOverride(name = "retailDistribInd", column = @Column(name = "RETAIL_DISTRIB_IND", length = 1)) })
	public CmcisBranchesId getId() {
		return this.id;
	}

	public void setId(CmcisBranchesId id) {
		this.id = id;
	}

	@ManyToOne(fetch = FetchType.LAZY)
	@JoinColumn(name = "MEMBER_NO", nullable = false, insertable = false, updatable = false)
	public CmcisMembersDomain getCmcisMembers() {
		return this.cmcisMembers;
	}

	public void setCmcisMembers(CmcisMembersDomain cmcisMembers) {
		this.cmcisMembers = cmcisMembers;
	}

}